DispatcherBuilder

Struct DispatcherBuilder 

pub struct DispatcherBuilder { /* private fields */ }
Available on crate feature dispatcher only.
A builder for Dispatcher.

Implementations

Source

impl DispatcherBuilder

pub fn new() -> DispatcherBuilder

Create a builder with default settings.

pub fn concurrent(self, concurrent: bool) -> DispatcherBuilder

If execute tasks concurrently. Default to be true.

When set to false, tasks are executed sequentially without any concurrency within the thread.

pub fn worker_threads(self, nthreads: NonZero<usize>) -> DispatcherBuilder

Set the number of worker threads of the dispatcher. The default value is the CPU number. If the CPU number could not be retrieved, the default value is 1.

pub fn stack_size(self, s: usize) -> DispatcherBuilder

Set the size of stack of the worker threads.

pub fn block_signals(self, block_signals: bool) -> DispatcherBuilder

Block standard signals on worker threads.

Default to true. When enabled, SIGINT, SIGTERM, SIGQUIT, SIGHUP, SIGUSR1, SIGUSR2, and SIGPIPE are masked on worker threads.

This option only has effect on Unix systems. On non-Unix systems, this method does nothing.

On Unix systems, when Dispatcher spawns worker threads, they inherit the parent thread’s signal mask. By default, SIGINT (Ctrl-C) and other signals can be delivered to any thread in the process. If a worker thread receives the signal before the async signal handler is polled on the main thread, the default signal handler runs (terminating the process) instead of the compio signal handler.

This is a well-known issue in multi-threaded Unix applications and requires explicit signal masking.

pub fn thread_affinity( self, f: impl FnMut(usize) -> HashSet<usize> + 'static, ) -> DispatcherBuilder

Set the thread affinity for the dispatcher.

pub fn thread_names( self, f: impl FnMut(usize) -> String + 'static, ) -> DispatcherBuilder

Provide a function to assign names to the worker threads.

pub fn proactor_builder(self, builder: ProactorBuilder) -> DispatcherBuilder

Set the proactor builder for the inner runtimes.

pub fn build(self) -> Result<Dispatcher, Error>

Build the Dispatcher.